@@ -1,14 +1,14 @@
-#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>#
-#  Chart::Bars                #
-#                             #
-#  written by david bonner    #
-#  dbonner@cs.bu.edu          #
-#                             #
-#  maintained by peter clark  #
-#  ninjaz@webexpress.com      #
-#                             #
-#  theft is treason, citizen  #
-#<<<<<<<<<<<<<<<<<<<<<<<<<<<<<#
+#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>#
+#  Chart::Bars                   #
+#                                #
+#  written by david bonner       #
+#  dbonner@cs.bu.edu             #
+#                                #
+#  maintained by the Chart Group #
+#  Chart@wettzell.ifag.de        #
+#                                #
+#  theft is treason, citizen     #
+#<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<#
 
 package Chart::Bars;
 
@@ -18,7 +18,9 @@ use Carp;
 use strict;
 
 @Chart::Bars::ISA = qw(Chart::Base);
-$Chart::Bars::VERSION = 0.99;
+$Chart::Bars::VERSION = 1.0;
+
+my $DEBUG = 0;
 
 #>>>>>>>>>>>>>>>>>>>>>>>>>>#
 #  public methods go here  #
@@ -34,7 +36,7 @@ $Chart::Bars::VERSION = 0.99;
 sub _draw_data {
   my $self = shift;
   my $data = $self->{'dataref'};
-  my $misccolor = $self->{'color_table'}{'misc'};
+  my $misccolor = $self->_color_role_to_index('misc');
   my ($x1, $x2, $x3, $y1, $y2, $y3);
   my ($width, $height, $delta1, $delta2, $map, $mod);
   my ($i, $j, $color);
@@ -79,7 +81,7 @@ sub _draw_data {
   # draw the bars
   for $i (1..$self->{'num_datasets'}) {
     # get the color for this dataset
-    $color = $self->{'color_table'}{'dataset'.($i-1)};
+    $color = $self->_color_role_to_index('dataset'.($i-1));
 
     # draw every bar for this dataset
     for $j (0..$self->{'num_datapoints'}) {
@@ -97,6 +99,11 @@ sub _draw_data {
 	$y3 = $y1 - (($data->[$i][$j] - $mod) * $map);
 
 	# draw the bar
+        printf "Rectangle  %7.2f,%7.2f,%7.2f,%7.2f\n",$x2,$y3,$x3,$y2 if $DEBUG;
+        if ( $y3 < $self->{'curr_y_min'} ) {
+           $y3 = $self->{'curr_y_min'};
+           printf "corrected: %7.2f,%7.2f,%7.2f,%7.2f\n",$x2,$y3,$x3,$y2 if $DEBUG;
+        }
 	## y2 and y3 are reversed in some cases because GD's fill
 	## algorithm is lame
 	if ($data->[$i][$j] > 0) {
